@@ -4,8 +4,8 @@ Contient la classe abstraite chargée de traiter, stocker et manipuler les infor
 from abc import abstractmethod
 from typing import List
 
-from src.BI_parser.bloc import Bloc
-from src.BI_parser.variable import Variable
+from BI_parser.bloc import Bloc
+from BI_parser.variable import Variable
 
 class Code(Bloc):
     '''
